@@ -40,6 +40,7 @@
 #include <sys/types.h>
 #include <sys/fcntl.h>
 #include <sys/termios.h>
+#include <sys/wait.h>
 #include <dirent.h>
 #include <unistd.h>
 #include <stdio.h>
@@ -48,9 +49,11 @@
 #include <pwd.h>
 #endif
 
+#include <dbus/dbus-glib.h>
 #include <glib/gi18n.h>
 #include <glib.h>
 #include <glib/gstdio.h>
+#include <gtk/gtk.h>
 
 #include <gconf/gconf-client.h>
 
@@ -175,6 +178,7 @@ anjuta_util_button_new_with_stock_image (const gchar* text,
 										 const gchar* stock_id)
 {
 	GtkWidget *button;
+	GtkWidget *child;
 	GtkStockItem item;
 	GtkWidget *label;
 	GtkWidget *image;
@@ -183,9 +187,9 @@ anjuta_util_button_new_with_stock_image (const gchar* text,
 
 	button = gtk_button_new ();
 
- 	if (GTK_BIN (button)->child)
-    		gtk_container_remove (GTK_CONTAINER (button),
-				      GTK_BIN (button)->child);
+	child = gtk_bin_get_child (GTK_BIN (button));
+	if (child)
+		gtk_container_remove (GTK_CONTAINER (button), child);
 
   	if (gtk_stock_lookup (stock_id, &item))
     	{
@@ -232,7 +236,7 @@ anjuta_util_dialog_add_button (GtkDialog *dialog, const gchar* text,
 	button = anjuta_util_button_new_with_stock_image (text, stock_id);
 	g_return_val_if_fail (button != NULL, NULL);
 
-	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (button, TRUE);
 
 	gtk_widget_show (button);
 
@@ -435,7 +439,7 @@ anjuta_util_dialog_input (GtkWindow *parent, const gchar *prompt,
 										  GTK_STOCK_OK, GTK_RESPONSE_OK,
 										  NULL);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
-	dialog_vbox = GTK_DIALOG (dialog)->vbox;
+	dialog_vbox = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 	gtk_window_set_default_size (GTK_WINDOW (dialog), 400, -1);
 	gtk_widget_show (dialog_vbox);
 	
@@ -479,6 +483,102 @@ anjuta_util_dialog_input (GtkWindow *parent, const gchar *prompt,
 	return (res == GTK_RESPONSE_OK);
 }
 
+static void
+on_install_files_done (DBusGProxy *proxy, DBusGProxyCall *call_id,
+					   gpointer user_data)
+{
+	GError *error = NULL;
+	dbus_g_proxy_end_call (proxy, call_id, &error, G_TYPE_INVALID);
+	if (error)
+	{
+		/*
+		  Only dbus error is handled. Rest of the errors are from packagekit
+		  which have already been notified to user by packagekit.
+		*/
+		if (error->domain == DBUS_GERROR)
+		{
+			const gchar *error_message = NULL;
+
+			/* Service error which implies packagekit is missing */
+			if (error->code == DBUS_GERROR_SERVICE_UNKNOWN)
+			{
+				error_message = _("You do not seem to have PackageKit installed. PackageKit is required for installing missing packages. Please install \"packagekit-gnome\" package from your distribution, or install the missing packages manually.");
+			}
+			/* General dbus error implies failure to call dbus method */
+			else if (error->code != DBUS_GERROR_REMOTE_EXCEPTION &&
+					 error->code != DBUS_GERROR_NO_REPLY)
+			{
+				error_message = error->message;
+			}
+			if (error_message)
+				anjuta_util_dialog_error (NULL,
+										  _("Installation failed: %s"),
+										  error_message);
+		}
+		g_error_free (error);
+	}
+}
+
+gboolean
+anjuta_util_install_files (const gchar * const names)
+{
+	DBusGConnection * connection;
+	DBusGProxy * proxy;
+	guint32 xid = 0;
+	gchar ** pkgv;
+
+	if (!names)
+		return FALSE;
+
+	connection = dbus_g_bus_get (DBUS_BUS_SESSION, NULL);
+	if (!connection)
+		return FALSE;
+
+	proxy = dbus_g_proxy_new_for_name (connection,
+									   "org.freedesktop.PackageKit",
+									   "/org/freedesktop/PackageKit",
+									   "org.freedesktop.PackageKit.Modify");
+	if (!proxy)
+		return FALSE;
+
+	pkgv = g_strsplit (names, ", ", 0);
+	dbus_g_proxy_begin_call (proxy, "InstallProvideFiles",
+							 on_install_files_done, NULL, NULL,
+							 G_TYPE_UINT, xid,
+							 G_TYPE_STRV, pkgv,
+							 G_TYPE_STRING, "",
+							 G_TYPE_INVALID, G_TYPE_INVALID);
+	g_strfreev (pkgv);
+	return TRUE;
+}
+
+gboolean
+anjuta_util_package_is_installed (const gchar * package, gboolean show)
+{
+	gboolean installed = FALSE;
+	int status;
+	int exit_status;
+	pid_t pid;
+
+	if ((pid = fork()) == 0)
+		execlp ("pkg-config", "pkg-config", "--exists", package, NULL);
+
+	waitpid (pid, &status, 0);
+	exit_status = WEXITSTATUS (status);
+	installed = (exit_status == 0) ? TRUE : FALSE;
+	if (installed)
+		return TRUE;
+
+	if (show)
+	{
+		anjuta_util_dialog_error (NULL,
+								  _("The \"%s\" package is not installed.\n"
+									"Please install it."), package);
+	}
+
+	return FALSE;
+}
+
 gboolean
 anjuta_util_prog_is_installed (const gchar * prog, gboolean show)
 {
