@@ -1,45 +1,55 @@
 
--- FOREIGN keys are not supported. http://www.sqlite.org/omitted.html
+-- FIXME: FOREIGN keys are now supported. schema should enforces them.
+-- Right now the support here is disabled.
 
+DROP TABLE IF EXISTS workspace;
 CREATE TABLE workspace (workspace_id integer PRIMARY KEY AUTOINCREMENT,
                         workspace_name varchar (50) not null unique,
                         analyse_time DATE
                         );
 
+DROP TABLE IF EXISTS project;
 CREATE TABLE project (project_id integer PRIMARY KEY AUTOINCREMENT,
                       project_name varchar (50) not null unique,
                       wrkspace_id integer REFERENCES workspace (workspace_id),
                       analyse_time DATE
                       );
-                    
+
+DROP TABLE IF EXISTS file_include;
 CREATE TABLE file_include (file_include_id integer PRIMARY KEY AUTOINCREMENT,
                            file_include_type varchar (10) not null unique
                            );
 
+DROP TABLE IF EXISTS ext_include;
 CREATE TABLE ext_include (prj_id integer REFERENCES project (project_id),
                           file_incl_id integer REFERENCES file_include (file_include_id),
                           PRIMARY KEY (prj_id, file_incl_id)
                           );
-                          
+
+DROP TABLE IF EXISTS file_ignore;
 CREATE TABLE file_ignore (file_ignore_id integer PRIMARY KEY AUTOINCREMENT,
                           file_ignore_type varchar (10) unique                          
                           );
 
+DROP TABLE IF EXISTS ext_ignore;
 CREATE TABLE ext_ignore (prj_id integer REFERENCES project (project_id),
                          file_ign_id integer REFERENCES file_ignore (file_ignore_id),
                          PRIMARY KEY (prj_id, file_ign_id)
                          );
-                         
+
+DROP TABLE IF EXISTS file;
 CREATE TABLE file (file_id integer PRIMARY KEY AUTOINCREMENT,
                    file_path TEXT not null unique,
                    prj_id integer REFERENCES project (projec_id),
                    lang_id integer REFERENCES language (language_id),
                    analyse_time DATE
                    );
-                   
+
+DROP TABLE IF EXISTS language;
 CREATE TABLE language (language_id integer PRIMARY KEY AUTOINCREMENT,
                        language_name varchar (50) not null unique);
 
+DROP TABLE IF EXISTS symbol;
 CREATE TABLE symbol (symbol_id integer PRIMARY KEY AUTOINCREMENT,
                      file_defined_id integer not null REFERENCES file (file_id),
                      name varchar (256) not null,
@@ -53,89 +63,82 @@ CREATE TABLE symbol (symbol_id integer PRIMARY KEY AUTOINCREMENT,
                      kind_id integer REFERENCES sym_kind (sym_kind_id),
                      access_kind_id integer REFERENCES sym_access (sym_access_id),
                      implementation_kind_id integer REFERENCES sym_implementation (sym_impl_id),
-					 update_flag integer default 0,
+                     update_flag integer default 0,
                      unique (name, file_defined_id, file_position)
                      );
-                     
+
+DROP TABLE IF EXISTS sym_type;
 CREATE TABLE sym_type (type_id integer PRIMARY KEY AUTOINCREMENT,
                    type_type varchar (256) not null,
                    type_name varchar (256) not null,
                    unique (type_type, type_name)
                    );
 
+DROP TABLE IF EXISTS sym_kind;
 CREATE TABLE sym_kind (sym_kind_id integer PRIMARY KEY AUTOINCREMENT,
                        kind_name varchar (50) not null unique
                        );
 
+DROP TABLE IF EXISTS sym_access;
 CREATE TABLE sym_access (access_kind_id integer PRIMARY KEY AUTOINCREMENT,
                          access_name varchar (50) not null unique
                          );
 
+DROP TABLE IF EXISTS sym_implementation;
 CREATE TABLE sym_implementation (sym_impl_id integer PRIMARY KEY AUTOINCREMENT,
                                  implementation_name varchar (50) not null unique
                                  );
 
+DROP TABLE IF EXISTS heritage;
 CREATE TABLE heritage (symbol_id_base integer REFERENCES symbol (symbol_id),
                        symbol_id_derived integer REFERENCES symbol (symbol_id),
                        PRIMARY KEY (symbol_id_base, symbol_id_derived)
                        );
-                       
+
+DROP TABLE IF EXISTS scope;
 CREATE TABLE scope (scope_id integer PRIMARY KEY AUTOINCREMENT,
                     scope_name varchar(256) not null,
                     type_id integer,
                     unique (scope_name, type_id)
                     );
 
+DROP TABLE IF EXISTS version;
 CREATE TABLE version (sdb_version numeric PRIMARY KEY);
 
+DROP TABLE IF EXISTS __tmp_heritage_scope;
 CREATE TABLE __tmp_heritage_scope (tmp_heritage_scope_id integer PRIMARY KEY AUTOINCREMENT,
-							symbol_referer_id integer not null,
-							field_inherits varchar(256),
-							field_struct varchar(256),
-							field_typeref varchar(256),
-							field_enum varchar(256),
-							field_union varchar(256),
-							field_class varchar(256),
-							field_namespace varchar(256)
-							);
+                            symbol_referer_id integer not null,
+                            field_inherits varchar(256),
+                            field_struct varchar(256),
+                            field_typeref varchar(256),
+                            field_enum varchar(256),
+                            field_union varchar(256),
+                            field_class varchar(256),
+                            field_namespace varchar(256)
+                            );
 
+DROP TABLE IF EXISTS __tmp_removed;
 CREATE TABLE __tmp_removed (tmp_removed_id integer PRIMARY KEY AUTOINCREMENT,
-							symbol_removed_id integer not null
-							);
-
--- test on 250 .c files.
--- all indexes disabled: 13.1 ms/symbol; after pragmas: 11.9
--- all indexes enabled: 14.3 ms/symbol
--- symbol_idx_1 enabled: 13.4 ms/symbol
--- unique keys (symbol_idx_2, scope_idx_2, file_idx_1, sym_type_idx_2): 13.3
--- symbol_idx_1, symbol_idx_3, symbol_idx_4, scope_idx_1, sym_type_idx_1: 13.9
-
---CREATE INDEX symbol_idx_1 ON symbol (name);
-
---not needed CREATE INDEX symbol_idx_2 ON symbol (name, file_defined_id, file_position);
+                            symbol_removed_id integer not null
+                            );
 
+DROP INDEX IF EXISTS symbol_idx_3;
 CREATE INDEX symbol_idx_3 ON symbol (name, file_defined_id, type_id);
 
+DROP INDEX IF EXISTS symbol_idx_4;
 CREATE INDEX symbol_idx_4 ON symbol (scope_id);
 
+DROP INDEX IF EXISTS symbol_idx_5;
 CREATE INDEX symbol_idx_5 ON symbol (type_id);
 
---CREATE INDEX scope_idx_1 ON scope (scope_name);
-
---not needed CREATE INDEX scope_idx_2 ON scope (scope_name, type_id);
-
---not needed CREATE INDEX file_idx_1 ON file (file_path);
-
---CREATE INDEX sym_type_idx_1 ON sym_type (type_type);
-
---not needed CREATE INDEX sym_type_idx_2 ON sym_type (type_type, type_name);
-
+DROP TRIGGER IF EXISTS delete_file_trg;
 CREATE TRIGGER delete_file_trg BEFORE DELETE ON file
 FOR EACH ROW
 BEGIN
 	DELETE FROM symbol WHERE file_defined_id = old.file_id;
 END;
 
+DROP TRIGGER IF EXISTS delete_symbol_trg;
 CREATE TRIGGER delete_symbol_trg BEFORE DELETE ON symbol
 FOR EACH ROW
 BEGIN
@@ -151,3 +154,4 @@ PRAGMA temp_store = MEMORY;
 PRAGMA case_sensitive_like = 1;
 PRAGMA journal_mode = OFF;
 PRAGMA read_uncommitted = 1;
+PRAGMA foreign_keys = OFF;
